summaryrefslogtreecommitdiffstats
path: root/libk9copy/k9dvdchapter.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-05-27 23:37:00 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-05-27 23:37:00 +0000
commitb0e912c8b3d02a518fedda28c3180eb4794a7520 (patch)
tree07d344862562fab58cbe2df39d13d16f2e4d2bea /libk9copy/k9dvdchapter.cpp
parent4d695ec81fe4d4335ee82c7a9346ad9c9e144ecc (diff)
downloadk9copy-b0e912c8b3d02a518fedda28c3180eb4794a7520.tar.gz
k9copy-b0e912c8b3d02a518fedda28c3180eb4794a7520.zip
TQt4 convert k9copy
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/k9copy@1233843 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'libk9copy/k9dvdchapter.cpp')
-rw-r--r--libk9copy/k9dvdchapter.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/libk9copy/k9dvdchapter.cpp b/libk9copy/k9dvdchapter.cpp
index e96385e..9268bbe 100644
--- a/libk9copy/k9dvdchapter.cpp
+++ b/libk9copy/k9dvdchapter.cpp
@@ -18,8 +18,8 @@ const int& k9DVDChapter::getnum()
{
return num;
}
-/** Read property of QTime length. */
-const QTime& k9DVDChapter::getlength()
+/** Read property of TQTime length. */
+const TQTime& k9DVDChapter::getlength()
{
return length;
}
@@ -30,7 +30,7 @@ const int& k9DVDChapter::getsectors()
return sectors;
}
-const QTime& k9DVDChapter::gettime()
+const TQTime& k9DVDChapter::gettime()
{
return time;
}